@@ -6,7 +6,7 @@
 # Last changed: 04 NOV 2005
 
 addSignifFeatureData <- function(x,SignifFeatureData,featureCol,dest,
-   trans.alpha=1)
+   trans.alpha=1,rgl=FALSE)
 {
   if (is.vector(x))
     d <- 1
@@ -28,7 +28,10 @@ addSignifFeatureData <- function(x,SignifFeatureData,featureCol,dest,
       if (is.vector(x.sig))
         x.sig <- matrix(x.sig, nrow=1)
       
-      rgl::points3d(x.sig[,1],x.sig[,2], x.sig[,3], size=3,color=featureCol, alpha=trans.alpha)           
+      if (!rgl)
+         plot3D::points3D(x.sig[,1],x.sig[,2], x.sig[,3], pch=16, col=featureCol, alpha=trans.alpha, theta=-30, phi=40, d=4, add=TRUE) 
+      else
+         rgl::points3d(x.sig[,1],x.sig[,2], x.sig[,3], size=3, color=featureCol, alpha=trans.alpha)           
     }
   }
   
@@ -40,7 +43,10 @@ addSignifFeatureData <- function(x,SignifFeatureData,featureCol,dest,
       if (is.vector(x.sig))
         x.sig <- matrix(x.sig, nrow=1)
       
-      rgl::points3d(x.sig[,1],x.sig[,2], x.sig[,3], size=3,color=featureCol, alpha=trans.alpha)  
+      if (!rgl)
+         plot3D::points3D(x.sig[,1],x.sig[,2], x.sig[,3], pch=16, col=featureCol, alpha=trans.alpha, add=TRUE) 
+      else
+      	 rgl::points3d(x.sig[,1],x.sig[,2], x.sig[,3], size=3, color=featureCol, alpha=trans.alpha)  
     }
   }
 }
